==> anon-proxy_00.02.29.orig.tar.gz: anon-proxy-00.02.29/CAPool.hpp <==
/*
Copyright (c) 2000, The JAP-Team 
All rights reserved.
Redistribution and use in source and binary forms, with or without modification, 
are permitted provided that the following conditions are met:

	- Redistributions of source code must retain the above copyright notice, 
	  this list of conditions and the following disclaimer.

	- Redistributions in binary form must reproduce the above copyright notice, 
	  this list of conditions and the following disclaimer in the documentation and/or 
		other materials provided with the distribution.

	- Neither the name of the University of Technology Dresden, Germany nor the names of its contributors 
	  may be used to endorse or promote products derived from this software without specific 
		prior written permission. 

	
THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS'' AND ANY EXPRESS 
OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY 
AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS
BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, 
OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER 
IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE
*/
#ifndef __CAPOOL__
#define __CAPOOL__
#include "CAMuxSocket.hpp"

struct t_pool_list
	{
		struct t_pool_list * next;
		MIXPACKET mixpacket;
	};

typedef t_pool_list tPoolListEntry;

/** This class implements the pool strategie of a Mix. See \ref docSectionPool "[Message Pool]" for more information.
	*/
class CAPool
	{
		public:
			CAPool(UINT32 poolsize);
			~CAPool();
			
			SINT32 pool(MIXPACKET* pMixPacket); 
		
		private:
			tPoolListEntry* m_pPoolList;
			tPoolListEntry* m_pLastEntry;
			tPoolListEntry* m_pEntry;
			UINT32 m_uPoolSize;
		
	};
#endif

==> anon-proxy_00.05.38+20081230.orig.tar.gz: anon-proxy-00.05.38+20081230/CAPool.hpp <==
/*
Copyright (c) 2000, The JAP-Team 
All rights reserved.
Redistribution and use in source and binary forms, with or without modification, 
are permitted provided that the following conditions are met:

	- Redistributions of source code must retain the above copyright notice, 
	  this list of conditions and the following disclaimer.

	- Redistributions in binary form must reproduce the above copyright notice, 
	  this list of conditions and the following disclaimer in the documentation and/or 
		other materials provided with the distribution.

	- Neither the name of the University of Technology Dresden, Germany nor the names of its contributors 
	  may be used to endorse or promote products derived from this software without specific 
		prior written permission. 

	
THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS'' AND ANY EXPRESS 
OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY 
AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS
BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, 
OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER 
IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE
*/
#ifndef __CAPOOL__
#define __CAPOOL__
#include "CAMuxSocket.hpp"
	
struct t_pool_list
	{
		struct t_pool_list * next;
		tPoolEntry poolentry;
	};

typedef t_pool_list tPoolListEntry;

/** This class implements the pool strategie of a Mix. See \ref docSectionPool "[Message Pool]" for more information.
	*/
class CAPool
	{
		public:
			CAPool(UINT32 poolsize);
			~CAPool();
			
			SINT32 pool(tPoolEntry* pPoolEntry); 
		
		private:
			tPoolListEntry* m_pPoolList;
			tPoolListEntry* m_pLastEntry;
			tPoolListEntry* m_pEntry;
			HCHANNEL* m_arChannelIDs;
			UINT32 m_uPoolSize;
			UINT32 m_uRandMax;
	};
#endif
